@@ -55,7 +55,9 @@ static void sdcard_hotplug(int insert)
 
 static int sdcardmgr_getstatus(void)
 {
-#ifdef CONFIG_ARCH_PXA_CORGI
+#ifdef CONFIG_ARCH_PXA_AKITA
+    if ( GPLR(GPIO9_MMCCS1) & GPIO_bit(GPIO9_MMCCS1) ) {
+#elif CONFIG_ARCH_PXA_CORGI
     if ( GPLR(GPIO9_MMCCS1) & GPIO_bit(GPIO9_MMCCS1) ) {
 #elif CONFIG_ARCH_PXA_TOSA
     if ( GPLR(GPIO9_MMCCS1) & GPIO_bit(GPIO9_MMCCS1) ) {
@@ -94,16 +96,25 @@ static void sdcardirq_handler()
 
 static int install_sdcardirq(void)
 {
-#ifdef CONFIG_ARCH_PXA_CORGI
+#ifdef CONFIG_ARCH_PXA_AKITA
     CKEN &= ~CKEN12_MMC;
-#endif
-#ifdef CONFIG_ARCH_PXA_TOSA
+#elif CONFIG_ARCH_PXA_CORGI
+    CKEN &= ~CKEN12_MMC;
+#elif CONFIG_ARCH_PXA_TOSA
     CKEN &= ~CKEN12_MMC;
 #endif
+
 #if defined(CONFIG_ARCH_SHARP_SL) && defined(CONFIG_APM_CPU_IDLE)
     lock_FCS(LOCK_FCS_MMC, 0);
 #endif
-#ifdef CONFIG_ARCH_PXA_CORGI
+
+#ifdef CONFIG_ARCH_PXA_AKITA
+    set_GPIO_mode( GPIO32_MMCCLK_MD );
+    set_GPIO_IRQ_edge( GPIO_nSD_DETECT, GPIO_BOTH_EDGES );
+    GPDR(GPIO9_MMCCS1) &= ~GPIO_bit(GPIO9_MMCCS1);
+    if (request_irq(IRQ_GPIO_nSD_DETECT, sdcardirq_handler, SA_SHIRQ, "sdcardirq", sdcardirq_handler)) {
+	printk(KERN_NOTICE "sdcardmgr: Couldn't get irq %d\n", IRQ_GPIO_nSD_DETECT);
+#elif CONFIG_ARCH_PXA_CORGI
     set_GPIO_mode( GPIO6_MMCCLK_MD );
     set_GPIO_IRQ_edge( GPIO_nSD_DETECT, GPIO_BOTH_EDGES );
     GPDR(GPIO9_MMCCS1) &= ~GPIO_bit(GPIO9_MMCCS1);
@@ -134,7 +145,9 @@ static int install_sdcardirq(void)
 
 static int deinstall_sdcardirq(void)
 {
-#ifdef CONFIG_ARCH_PXA_CORGI
+#ifdef CONFIG_ARCH_PXA_AKITA
+    free_irq(IRQ_GPIO_nSD_DETECT, sdcardirq_handler);
+#elif CONFIG_ARCH_PXA_CORGI
     free_irq(IRQ_GPIO_nSD_DETECT, sdcardirq_handler);
 #elif CONFIG_ARCH_PXA_TOSA
     free_irq(IRQ_GPIO_nSD_DETECT, sdcardirq_handler);
